//
//    Copyright 2005, Thomas C. McDermott, N5EG
//    This file is part of SIGGEN - the Signal Generator program.
//
//    SIGGEN is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    SIGGEN is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SIGGEN, if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
#pragma once

using namespace System;
using namespace System::ComponentModel;
using namespace System::Collections;
using namespace System::Windows::Forms;
using namespace System::Data;
using namespace System::Drawing;
using namespace System::Drawing::Drawing2D;


namespace AnalogMeter
{
	/// <summary> 
	/// Summary for AnalogMeterControl
	/// </summary>
	///
	/// WARNING: If you change the name of this class, you will need to change the 
	///          'Resource File Name' property for the managed resource compiler tool 
	///          associated with all .resx files this class depends on.  Otherwise,
	///          the designers will not be able to interact properly with localized
	///          resources associated with this form.
	public __gc class AnalogMeterControl : public System::Windows::Forms::UserControl
	{	
	public:
		AnalogMeterControl(void)	
		{
			InitializeComponent();
		}
		
	protected:
		void Dispose(Boolean disposing)	
		{
			if (disposing && components)
			{
				components->Dispose();
			}
			__super::Dispose(disposing);
		}

	protected: virtual void OnPaint(PaintEventArgs* e)	// redraw our control if paint event
		{
			__super::OnPaint(e);						// repaint our base class first
			Graphics* g = e->Graphics;
			DrawMeter(g);
		}



	public: int MeterValue;							// analog value to display on the meter
														// properties
	int get_Metervalue(void) { return(MeterValue); };
	void set_Metervalue(int mv) { MeterValue = mv; };

	private: void DrawMeter(Graphics * g)				// draw the meter within the control
		{

			int Left = this->ClientRectangle.Left;
			int Top = this->ClientRectangle.Top;
			int Width = this->ClientRectangle.Width;
			int Height = this->ClientRectangle.Height;
			Rectangle MeterBox = Rectangle(Left+4, Top+1, Width-8, Height-1);
			Rectangle ArcBox = Rectangle(Left-75, Top+20, Width+150, Height*2);
			Rectangle NeedleBox = Rectangle(Left-70, Top+10, Width+140, Height*2);
			Point LeftSign = Point(Left+40, Top+Height/3);
			Point RightSign = Point(Width-50, Top+Height/3);


			GraphicsPath* gp = new GraphicsPath();
			gp->AddRectangle(MeterBox);

			Pen* penBlack = new Pen(Color::Black);
			Pen* penDashedBlack = new Pen(Color::Black);
			penDashedBlack->DashStyle = DashStyle::Dash;
			Pen* penRed = new Pen(Color::Red);
			Pen* penThickBlack = new Pen(Color::Black, 2);
			SolidBrush* brush1 = new SolidBrush(Color::Black);
			System::Drawing::Font * Titlefont = new System::Drawing::Font("Arial", 20, FontStyle::Bold);

            g->DrawString(S"-", Titlefont, brush1, LeftSign);	
            g->DrawString(S"+", Titlefont, brush1, RightSign);	


			g->DrawRectangle(penBlack,Left, Top, Width-1, Height-1);

			g->SetClip(gp);						// make some empty space inside meter box
			g->DrawEllipse(penThickBlack, ArcBox);	// draw meter scale arc


			// draw meter needle
			// -180 points the meter to the left, 0 points it straight up, +180 points it to the right
			// use linear approximation for angle instead of arc (not too bad if the arc is fairly flat)
			// Fudge factor overscans needle to compensate for corner of meterbox not matching corner of arc

//			int EndPosition = Width/2 + (int)MeterValue * Width / 360;
			int EndPosition = Width/2 + (int)MeterValue * Width / 280;


			Point MeterOrigin = Point(Width/2, Height-20);	// pivot point of the meter
			Point MeterEnd = Point(EndPosition,Top+10);		// end point of meter
			g->ResetClip();
			gp->Reset();
			gp->AddEllipse(NeedleBox);
			g->SetClip(gp);								// setup clipping region arc so needle stays constant length
			g->DrawLine(penDashedBlack, MeterOrigin, Point(Width/2, Top)); // center line where phase = 0
			g->DrawLine(penRed, MeterOrigin, MeterEnd);	// draw meter needle


			


		}



	private:
		/// <summary>
		/// Required designer variable.
		/// </summary>
		System::ComponentModel::Container* components;

		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		void InitializeComponent(void)
		{
			// 
			// AnalogMeterControl
			// 
			this->Name = S"AnalogMeterControl";

		}
	};
}	// end namespace AnalogMeter


