//
//    Copyright 2004, Thomas C. McDermott, N5EG
//    This file is part of VNAR - the Vector Network Analyzer program.
//
//    VNAR is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    VNAR is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with VNAR, if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
#pragma	once

//	Constants.h
//
//	07-25-04	TCM	Original
//
//
//	Constants for the VNA instrument + others.
//

#define	VNA_XTAL_CONST	0xEE9BF				// translate VNA Xtal Osc to DDS divisor
	// the VNA crystal is ~12.000 MHz. It gets multiplied by 24 going to the DDS accumulator 
	// The clock rate is thus approximately 24 * ~12.000 MHz. = ~288.000 MHz.
	// The synthesizer accumulator value needed is:   N = Fdesired * 2^48 / Fclk
	// The constant 2^48/Fclk is 0xEE9BF, but can vary slightly for each oscillator module.


#define RAD2DEGR 180.0/3.14159265358	// Converts radians to degrees
#define DEGR2RAD 3.14159265358/180.0		// Converts degrees to radians

// Unused (old) constants before detector cal routines added...
//#define MAXREADP 3800					// Full-scale phase reading observed on S/N 1
//#define MINREADP   90					// Minimum-scale phase reading observed on S/N 1
//const int MIDREADP = MAXREADP/2;		// Mid-scale phase reading
//#define MODMIDREADP (MAXREADP+MINREADP)/2  // modified mid-scale phase reading

//const int UPLIMITP = MAXREADP - MAXREADP/4;	// Phase readings upper quartile
//const int DNLIMITP = MAXREADP/4	;		// Phase readings lower quartile



//	Constants related to the actual numeric VNA instrument readings
//  These are used until the Detector Calibration is run
#define MAXREFLMAGNITUDE 2100			// temporary until CALIBRATION is designed,
										// observed on S/N 1
#define MAXTRANMAGNITUDE 3800			// temporary until CALIBRATION is designed,
										// observed on S/N 1


#define MAXCALFREQ 120000000.0			// Calibration parameters
#define MINCALFREQ 200000.0
#define NUMCALPTS 1024.0



#define MAX_DDS_LEVEL	0xFFF				// Multiplier for DDS Amplitude, unsigned 12-bit int. Maximum = 0xFFF

// if MAX_DDS_LEVEL changes, then the three constants below change also since they reference the I-DAC

#define ONEDB_DDS_LEVEL	0xE40				// -1 db below maximum (max * 0.891)
#define TWODB_DDS_LEVEL 0xCB3				// -2 db below maximum (max * 0.794)
#define TWENTYDB_DDS_LEVEL 0x19A			// -20 db below maximum (max * 0.100)
//#define THIRTYTWODB_DDS_LEVEL 0x66			// -32 db below maximum (max * 0.025)
//#define THIRTYTHREEDB_DDS_LEVEL 0x5B		// -33 db below maximum (max * 0.022)
//#define THIRTYFOURDB_DDS_LEVEL 0x51			// -34 db below maximum (max * 0.020)
//#define FOURTYDB_DDS_LEVEL 0x28				// -40 db below maximum (max * 0.010)
//#define FIFTYTHREEDB_DDS_LEVEL 0x09			// -53 db below maximum (max * 0.0022)

//  this constant is not dependent on MAX_DDS_LEVEL since it references the Q-DAC
#define QDAC_ZERODBM	0xAAA				//0xAAA		// 0 dbm for Q-DAC ref level
											//0xFFF		// about +3.5 dB too hot for Q-DAC



